import { AfterContentChecked, QueryList, AfterContentInit, OnInit, NgZone, EventEmitter, ElementRef } from '@angular/core';
import { ListItemComponent, OptionSelectionChange } from '../list-item/list-item.component';
import { Observable } from 'rxjs';
import { ActiveDescendantKeyManager } from '@angular/cdk/a11y';
import { ControlValueAccessor } from '@angular/forms';
/** Change event object that is emitted when the select value has changed. */
export declare class SelectChange {
    source: SelectComponent;
    value: any;
    constructor(source: SelectComponent, value: any);
}
export declare class SelectComponent implements OnInit, AfterContentChecked, AfterContentInit, ControlValueAccessor {
    private _ngZone;
    private _selectionModel;
    private readonly _destroy;
    /** Manages keyboard events for options in the panel. */
    _keyManager: ActiveDescendantKeyManager<ListItemComponent>;
    overlayOpen: boolean;
    anchorWidth: any;
    /** @prop Optional CSS class name to md-list | '' */
    listClass: string;
    /** @prop Optional CSS button class name | '' */
    buttonClass: string;
    /** @prop Set the default selected option | '' */
    defaultValue: string;
    /** @prop Disable the Select Component | false */
    disabled: boolean;
    /** @prop Set ID for Select Component | null */
    id: string;
    /** @prop Optional prop to know if user is able to select multiple options | false */
    isMulti: boolean;
    /** @option Callback function invoked by user selecting an interactive option within list | null */
    /** ngModel of Select Control */
    ngModel: any;
    private _ngModelValue;
    select: EventEmitter<{}>;
    /** Event emitted when the selected value has been changed by the user. */
    readonly selectionChange: EventEmitter<SelectChange>;
    /** facilitates the two-way binding for the `ngModel` input. */
    readonly ngModelChange: EventEmitter<any>;
    originButton: any;
    /** Panel containing the select options. */
    panel: ElementRef;
    selectOptions: QueryList<ListItemComponent>;
    /** Combined stream of all of the child options' change events. */
    readonly optionSelectionChanges: Observable<OptionSelectionChange>;
    /** `View -> model callback called when value changes` */
    private _onChange;
    /** `View -> model callback called when select has been touched` */
    private _onTouched;
    /** Comparison function to specify which option is displayed. Defaults to object equality. */
    private _compareWith;
    /** Handles keyboard events when the selected is open. */
    _handleOpenKeydown: (event: any) => void;
    constructor(_ngZone: NgZone);
    ngOnInit(): void;
    ngAfterContentInit(): void;
    ngAfterContentChecked(): void;
    readonly buttonClasses: string;
    /** The currently selected option. */
    readonly selected: ListItemComponent | ListItemComponent[];
    /** Toggles the overlay panel open or closed. */
    toggle: () => void;
    open: () => void;
    close: () => void;
    /** Focuses the origin button of the select component. */
    focus: () => void;
    currentValue: () => any;
    /**
     * Sets the select's ngModelValue. Part of the ControlValueAccessor interface
     */
    writeValue: (value: any) => void;
    registerOnChange: (fn: (value: any) => void) => void;
    registerOnTouched: (fn: () => {}) => void;
    setDisabledState?: (isDisabled: boolean) => void;
    /** Sets the selected option based on a value. */
    private _setSelectionByValue;
    private _selectValue;
    private _propagateChanges;
    /** Sets up a key manager to listen to keyboard events on the overlay panel. */
    private _initKeyManager;
    /** Drops current option subscriptions and IDs and resets from scratch. */
    private _resetOptions;
    /** Invoked when an option is clicked. */
    private _onSelect;
    private _setAnchorWidth;
}
